==> biz-erp-2.2.0-20160913.123106-28-sources.jar: com/baijia/tianxiao/biz/erp/dto/CourseSigninRecordDto.java <==
package com.baijia.tianxiao.biz.erp.dto;

import java.util.List;
import java.util.Map;
import java.util.Set;

import com.baijia.tianxiao.biz.erp.dto.CourseSigninStsDto.StudentSigninSts;
import com.baijia.tianxiao.biz.erp.dto.response.LessonResponseDto;

/**   
 * @Title       : CourseSigninRecordDto 
 * @Description : 
 * @Author      : yuanxiaojun
 * @Date        : 2016年8月19日 下午2:23:33 
 * @Version     : v1.0   
 */
public class CourseSigninRecordDto {
	private Long courseId;//课程id
	private String courseName;//课程名称
	private Integer lessonNum;//已签到课次
	private Integer planNum;
	private Integer consumRuleValue;
	private String consumeRuleStr;
	private List<StudentSigninRecord> studentSigninRecordList;//学生签到记录列表
	private Map<String,Integer> signInStatusMap;
	private Set<String> studentLessonSet;
	private List<LessonResponseDto> lessonCourseList;

	
	public Integer getConsumRuleValue() {
		return consumRuleValue;
	}

	public void setConsumRuleValue(Integer consumRuleValue) {
		this.consumRuleValue = consumRuleValue;
	}

	public String getConsumeRuleStr() {
		return consumeRuleStr;
	}

	public void setConsumeRuleStr(String consumeRuleStr) {
		this.consumeRuleStr = consumeRuleStr;
	}

	public Long getCourseId() {
		return courseId;
	}

	public void setCourseId(Long courseId) {
		this.courseId = courseId;
	}

	public String getCourseName() {
		return courseName;
	}

	public void setCourseName(String courseName) {
		this.courseName = courseName;
	}

	public Integer getLessonNum() {
		return lessonNum;
	}

	public void setLessonNum(Integer lessonNum) {
		this.lessonNum = lessonNum;
	}

	public Integer getPlanNum() {
		return planNum;
	}

	public void setPlanNum(Integer planNum) {
		this.planNum = planNum;
	}

	public List<StudentSigninRecord> getStudentSigninRecordList() {
		return studentSigninRecordList;
	}

	public void setStudentSigninRecordList(List<StudentSigninRecord> studentSigninRecordList) {
		this.studentSigninRecordList = studentSigninRecordList;
	}

	public Map<String, Integer> getSignInStatusMap() {
		return signInStatusMap;
	}

	public void setSignInStatusMap(Map<String, Integer> signInStatusMap) {
		this.signInStatusMap = signInStatusMap;
	}

	public List<LessonResponseDto> getLessonCourseList() {
		return lessonCourseList;
	}

	public void setLessonCourseList(List<LessonResponseDto> lessonCourseList) {
		this.lessonCourseList = lessonCourseList;
	}
	
	public Set<String> getStudentLessonSet() {
		return studentLessonSet;
	}

	public void setStudentLessonSet(Set<String> studentLessonSet) {
		this.studentLessonSet = studentLessonSet;
	}


	public static class StudentSigninRecord {
		private Long userId;
		private String studentName;
		private String stuPinyinName;
		private int signCount;//签到次数
		private int signedCount;//到课次数
		private int leaveCount;//请假次数
		private int absentCount;//缺席次数
		private int arrangeCount;//已排课次
		private int attendCount;//已上课次
		public Long getUserId() {
			return userId;
		}
		public void setUserId(Long userId) {
			this.userId = userId;
		}
		public String getStudentName() {
			return studentName;
		}
		public void setStudentName(String studentName) {
			this.studentName = studentName;
		}
		public String getStuPinyinName() {
			return stuPinyinName;
		}
		public void setStuPinyinName(String stuPinyinName) {
			this.stuPinyinName = stuPinyinName;
		}
		public int getSignCount() {
			return signCount;
		}
		public void setSignCount(int signCount) {
			this.signCount = signCount;
		}
		public int getSignedCount() {
			return signedCount;
		}
		public void setSignedCount(int signedCount) {
			this.signedCount = signedCount;
		}
		public int getLeaveCount() {
			return leaveCount;
		}
		public void setLeaveCount(int leaveCount) {
			this.leaveCount = leaveCount;
		}
		public int getAbsentCount() {
			return absentCount;
		}
		public void setAbsentCount(int absentCount) {
			this.absentCount = absentCount;
		}
		public int getArrangeCount() {
			return arrangeCount;
		}
		public void setArrangeCount(int arrangeCount) {
			this.arrangeCount = arrangeCount;
		}
		public int getAttendCount() {
			return attendCount;
		}
		public void setAttendCount(int attendCount) {
			this.attendCount = attendCount;
		}
	}
	
}

==> biz-erp-2.28.0-20170710.073138-118-sources.jar: com/baijia/tianxiao/biz/erp/dto/CourseSigninRecordDto.java <==
package com.baijia.tianxiao.biz.erp.dto;

import java.util.List;
import java.util.Map;
import java.util.Set;

import com.baijia.tianxiao.biz.erp.dto.CourseSigninStsDto.StudentSigninSts;
import com.baijia.tianxiao.biz.erp.dto.response.LessonResponseDto;
import com.baijia.tianxiao.sal.course.dto.SignStatusRemarkDto;

/**   
 * @Title       : CourseSigninRecordDto 
 * @Description : 
 * @Author      : yuanxiaojun
 * @Date        : 2016年8月19日 下午2:23:33 
 * @Version     : v1.0   
 */
public class CourseSigninRecordDto {
	private Long courseId;//课程id
	private String courseName;//课程名称
	private Integer lessonNum;//已签到课次
	private Integer planNum;
	private Integer consumRuleValue;
	private String consumeRuleStr;
	private List<StudentSigninRecord> studentSigninRecordList;//学生签到记录列表
	private Map<String,SignStatusRemarkDto> signInStatusMap;
	private Set<String> studentLessonSet;
	private List<LessonResponseDto> lessonCourseList;

	
	public Integer getConsumRuleValue() {
		return consumRuleValue;
	}

	public void setConsumRuleValue(Integer consumRuleValue) {
		this.consumRuleValue = consumRuleValue;
	}

	public String getConsumeRuleStr() {
		return consumeRuleStr;
	}

	public void setConsumeRuleStr(String consumeRuleStr) {
		this.consumeRuleStr = consumeRuleStr;
	}

	public Long getCourseId() {
		return courseId;
	}

	public void setCourseId(Long courseId) {
		this.courseId = courseId;
	}

	public String getCourseName() {
		return courseName;
	}

	public void setCourseName(String courseName) {
		this.courseName = courseName;
	}

	public Integer getLessonNum() {
		return lessonNum;
	}

	public void setLessonNum(Integer lessonNum) {
		this.lessonNum = lessonNum;
	}

	public Integer getPlanNum() {
		return planNum;
	}

	public void setPlanNum(Integer planNum) {
		this.planNum = planNum;
	}

	public List<StudentSigninRecord> getStudentSigninRecordList() {
		return studentSigninRecordList;
	}

	public void setStudentSigninRecordList(List<StudentSigninRecord> studentSigninRecordList) {
		this.studentSigninRecordList = studentSigninRecordList;
	}

	public Map<String, SignStatusRemarkDto> getSignInStatusMap() {
		return signInStatusMap;
	}

	public void setSignInStatusMap(Map<String, SignStatusRemarkDto> signInStatusMap) {
		this.signInStatusMap = signInStatusMap;
	}

	public List<LessonResponseDto> getLessonCourseList() {
		return lessonCourseList;
	}

	public void setLessonCourseList(List<LessonResponseDto> lessonCourseList) {
		this.lessonCourseList = lessonCourseList;
	}
	
	public Set<String> getStudentLessonSet() {
		return studentLessonSet;
	}

	public void setStudentLessonSet(Set<String> studentLessonSet) {
		this.studentLessonSet = studentLessonSet;
	}


	public static class StudentSigninRecord {
		private Long userId;
		private String studentName;
		private String stuPinyinName;
		private int signCount;//签到次数
		private int signedCount;//到课次数
		private int leaveCount;//请假次数
		private int absentCount;//缺席次数
		private int arrangeCount;//已排课次
		private int attendCount;//已上课次
		public Long getUserId() {
			return userId;
		}
		public void setUserId(Long userId) {
			this.userId = userId;
		}
		public String getStudentName() {
			return studentName;
		}
		public void setStudentName(String studentName) {
			this.studentName = studentName;
		}
		public String getStuPinyinName() {
			return stuPinyinName;
		}
		public void setStuPinyinName(String stuPinyinName) {
			this.stuPinyinName = stuPinyinName;
		}
		public int getSignCount() {
			return signCount;
		}
		public void setSignCount(int signCount) {
			this.signCount = signCount;
		}
		public int getSignedCount() {
			return signedCount;
		}
		public void setSignedCount(int signedCount) {
			this.signedCount = signedCount;
		}
		public int getLeaveCount() {
			return leaveCount;
		}
		public void setLeaveCount(int leaveCount) {
			this.leaveCount = leaveCount;
		}
		public int getAbsentCount() {
			return absentCount;
		}
		public void setAbsentCount(int absentCount) {
			this.absentCount = absentCount;
		}
		public int getArrangeCount() {
			return arrangeCount;
		}
		public void setArrangeCount(int arrangeCount) {
			this.arrangeCount = arrangeCount;
		}
		public int getAttendCount() {
			return attendCount;
		}
		public void setAttendCount(int attendCount) {
			this.attendCount = attendCount;
		}
	}
	
}
